@@ -1,12 +1,13 @@
 package Tcl::pTk;
 
-our ($VERSION) = ('1.06_01');
+our ($VERSION) = ('1.08_01');
 
 use strict;
 use Tcl;
 use Exporter ('import');
 use Scalar::Util (qw /blessed/); # Used only for its blessed function
 use AutoLoader; # Used for autoloading the Error routine
+use Time::HiRes; # Used for emulating timeofday()
 use vars qw(@EXPORT @EXPORT_OK %EXPORT_TAGS $platform @cleanup_refs $cleanup_queue_maxsize $cleanupPending);
 
 # Wait till we have 100 things to delete before we do cleanup
@@ -72,6 +73,9 @@ if($DEBUG){
 
 # Variable to indicate whether Tile/Ttk widgets are available
 our ( $_Tile_available );
+# Variable to indicate whether Tcl/Tk 8.5.9 or later, or Tile 0.8.4.0
+# for Tcl/Tk 8.4, is available; needed by certain features
+our ( $_Tile_ge_0840 );
 
 @Tcl::pTk::ISA = qw(Tcl);
 
@@ -875,6 +879,11 @@ sub MainWindow {
     # (included in Tcl/Tk 8.5+, or as an extension for Tcl/Tk 8.4)
     $Tcl::pTk::_Tile_available = $interp->pkg_require('tile');
     if ($Tcl::pTk::_Tile_available) {
+        # Certain features require Tcl/Tk 8.5.9 or later,
+        # or Tile 0.8.4.0 for Tcl/Tk 8.4
+        $Tcl::pTk::_Tile_ge_0840 = ($interp->Eval(
+            "package vcompare $Tcl::pTk::_Tile_available 0.8.4.0"
+        ) != -1);
         require Tcl::pTk::Tile;
         Tcl::pTk::Tile::_declareTileWidgets($interp);
     }
@@ -920,12 +929,7 @@ sub MainLoop {
 }
 
 # timeofday function for compatibility with Tk::timeofday
-sub timeofday {
-    my $int = (ref $_[0]?shift:$tkinterp);
-    my $t = $int->invoke("clock", "microseconds");
-    $t = $t/1e6;
-}
-
+*Tcl::pTk::timeofday = \&Time::HiRes::time;
 
 # DoOneEvent for compatibility with perl/tk
 sub DoOneEvent{
